@@ -19,7 +19,7 @@ import           Data.Group
 import           Data.Groupoid
 import           Data.Semigroup
 import           Data.Semigroupoid
-import           Prelude           hiding (id, (.))
+import           Prelude           ()
 
 -- | An 'Endomorphism' in a given 'Category' is a morphism from some
 --   object to itself.  The set of endomorphisms for a particular
@@ -35,4 +35,4 @@ instance Category k => Monoid (Endomorphism k a) where
   Endomorphism a `mappend` Endomorphism b = Endomorphism (a . b)
 
 instance (Category k, Groupoid k) => Group (Endomorphism k a) where
-  invert (Endomorphism a) = Endomorphism (inv a)
\ No newline at end of file
+  invert (Endomorphism a) = Endomorphism (inv a)
